==> owlapi-osgidistribution-4.2.5-sources.jar: org/semanticweb/owlapi/reasoner/ImportsClosureNotInProfileException.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner;

import org.semanticweb.owlapi.model.IRI;

/**
 * This exception indicates that the reasoner cannot handle the set of axioms
 * that are in the imports closure of the root ontology because the axioms fall
 * outside of the "largest" OWL profile (i.e. OWL2DL or OWL2EL or OWL2QL or
 * OWL2RL) that the reasoner can handle. The reasoner will indicate in this
 * exception which profile it expects the axioms to be in.
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 */
public class ImportsClosureNotInProfileException extends
        OWLReasonerRuntimeException {

    private static final long serialVersionUID = 40000L;
    private final IRI profile;

    /**
     * @param profile
     *        profile
     */
    public ImportsClosureNotInProfileException(IRI profile) {
        this.profile = profile;
    }

    /**
     * Gets the profile which the reasoner can handle.
     * 
     * @return The profile.
     */
    public IRI getProfile() {
        return profile;
    }
}

==> owlapi-osgidistribution-4.5.27-sources.jar: org/semanticweb/owlapi/reasoner/ImportsClosureNotInProfileException.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner;

import org.semanticweb.owlapi.model.IRI;

/**
 * This exception indicates that the reasoner cannot handle the set of axioms that are in the
 * imports closure of the root ontology because the axioms fall outside of the "largest" OWL profile
 * (i.e. OWL2DL or OWL2EL or OWL2QL or OWL2RL) that the reasoner can handle. The reasoner will
 * indicate in this exception which profile it expects the axioms to be in.
 * 
 * @author Matthew Horridge, The University of Manchester, Information Management Group
 * @since 3.0.0
 */
public class ImportsClosureNotInProfileException extends OWLReasonerRuntimeException {

    private static final long serialVersionUID = 40000L;
    private final IRI profile;

    /**
     * @param profile profile
     */
    public ImportsClosureNotInProfileException(IRI profile) {
        super("Imports closure not in profile: " + profile);
        this.profile = profile;
    }

    /**
     * Gets the profile which the reasoner can handle.
     * 
     * @return The profile.
     */
    public IRI getProfile() {
        return profile;
    }
}
